==> ideaIC-162.426.1-sources.jar: com/intellij/psi/impl/source/codeStyle/FormatterBasedLineIndentProvider.java <==
/*
 * Copyright 2000-2016 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.psi.impl.source.codeStyle;

import com.intellij.openapi.editor.Document;
import com.intellij.openapi.editor.Editor;
import com.intellij.openapi.project.Project;
import com.intellij.psi.PsiDocumentManager;
import com.intellij.psi.PsiFile;
import com.intellij.psi.codeStyle.CodeStyleManager;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

/**
 * Formatter-based line indent provider which calculates indent using formatting model.
 */
public class FormatterBasedLineIndentProvider implements LineIndentProvider {
  @Nullable
  @Override
  public String getLineIndent(@NotNull Project project, @NotNull Editor editor, int offset) {
    Document document = editor.getDocument();
    PsiDocumentManager.getInstance(project).commitDocument(document);
    return CodeStyleManager.getInstance(project).getLineIndent(document, offset);
  }

  @Override
  public boolean isSuitableFor(@Nullable PsiFile file) {
    return true;
  }
}

==> ideaIC-162.646.4-sources.jar: com/intellij/psi/impl/source/codeStyle/FormatterBasedLineIndentProvider.java <==
/*
 * Copyright 2000-2016 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.psi.impl.source.codeStyle;

import com.intellij.lang.Language;
import com.intellij.openapi.editor.Document;
import com.intellij.openapi.editor.Editor;
import com.intellij.openapi.project.Project;
import com.intellij.psi.PsiDocumentManager;
import com.intellij.psi.codeStyle.CodeStyleManager;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

/**
 * Formatter-based line indent provider which calculates indent using formatting model.
 */
public class FormatterBasedLineIndentProvider implements LineIndentProvider {
  @Nullable
  @Override
  public String getLineIndent(@NotNull Project project, @NotNull Editor editor, Language language, int offset) {
    Document document = editor.getDocument();
    PsiDocumentManager.getInstance(project).commitDocument(document);
    return CodeStyleManager.getInstance(project).getLineIndent(document, offset);
  }

  @Override
  public boolean isSuitableFor(@Nullable Language language) {
    return true;
  }
}
